@extends('cms::admin.layouts.app')

@section('content')
    <div class="card card-body">
        <div class="table-responsive">
            <table class="table table-styled">
                <thead>
                <tr>
                    <td data-colspan>
                        <form class="row" action="{{route('cms.products.index')}}">
                            <div class="col-12 col-sm-4 col-md-3">
                                @component('erp::components.filter')
                                    @slot('key', 'manufacture_id')
                                    @slot('placeholder', trans('erp::erp.manufactures'))
                                    @slot('value', old('manufacture_id',Request::query('manufacture_id')?? 0))
                                    @slot('options', $manufactures)
                                @endcomponent
                            </div>
                            <div class="col">
                                <input type="search" name="q" class="form-control"
                                       value="{{Request::query('q')}}"
                                       placeholder="@lang('erp::erp.search_product')">
                            </div>
                            <div class="col-auto">
                                <button class="btn btn-outline-success"><i class="fas fa-search"></i>
                                    <span class="d-none d-md-inline">@lang('erp::erp.search')</span></button>
                            </div>
                            <div class="input-group-append">
                            </div>
                        </form>
                    </td>
                </tr>
                <tr class="collspan-count">
                    <th class="fit-content">@sortablelink('sku', trans('erp::erp.sku'))</th>
                    <th class="fit-content">@sortablelink('product_name', trans('erp::erp.product_name'))</th>
                    <th class="fit-content">@sortablelink('manufacture.manufacture_name',
                        trans('erp::erp.manufacture_name'))
                    </th>
                    <th class="fit-content">@sortablelink('price', trans('erp::erp.price'))</th>
                    <th class="fit-content">@sortablelink('qty', trans('erp::erp.qty'))</th>
                    <th class="fit-content">@sortablelink('can_preorder', trans('erp::erp.preorder_allowed'))</th>
                    <th class="fit-content">@sortablelink('updated_at', trans('erp::erp.last_updated'))</th>
                    <th class="fit-content text-right"><a href="{{route('cms.products.create')}}"
                                                          class="btn btn-outline-primary btn-sm">

                            <i class="fas fa-plus-circle"></i>
                            <span class="d-none d-md-inline">@lang('erp::erp.create_new_product')</span>
                        </a></th>
                </tr>
                </thead>
                <tbody>
                @forelse($items as $product)
                    <tr>
                        <th class="text-nowrap">{{$product->sku}}</th>
                        <td>{{$product->product_name}}</td>
                        <td>
                            <a href="{{route('cms.manufactures.edit', $product->manufacture_id)}}">{{$product->manufacture->manufacture_name}}</a>
                        </td>
                        <td>{{$product->price}} / {{$product->special_price}}</td>
                        <td>{{$product->qty ?? 0}}</td>
                        <td class="text-center"><i
                                class="fa-2x fas {{$product->can_preorder? 'fa-check-circle text-success' : 'fa-times-circle text-danger' }}"></i>
                        </td>
                        <td class="text-right text-nowrap">
                            {{$product->updated_at}}
                        </td>
                        <td class="text-right text-nowrap">
                            <a href="{{route('cms.products.edit', $product->id)}}"
                               class="btn btn-outline-success btn-sm"><i class="fas fa-edit"></i>
                                <span class="d-none d-md-inline">@lang('erp::erp.edit_product')</span></a>

                            <form method="post" @submit="confirmDelete" class="d-inline"
                                  action="{{route('cms.products.destroy', $product->id)}}">
                                @csrf
                                @method('DELETE')
                                <button class="btn btn-outline-danger btn-sm">
                                    <i class="fas fa-trash"></i>
                                    <span class="d-none d-md-inline">@lang('cms-fixed::admin.delete')</span>
                                </button>
                            </form>
                        </td>
                    </tr>
                @empty
                    <tr>
                        <td class="text-muted text-center" colspan="5">@lang('cms-fixed::admin.no_data')</td>
                    </tr>
                @endforelse
                </tbody>
                <tfoot>
                <tr>
                    <td data-colspan="1"> {!! $items->appends(Request::except('page'))->render() !!}</td>
                    <td class="text-right"><a href="{{route('cms.products.create')}}"
                                              class="btn btn-outline-primary btn-sm">
                            <i class="fas fa-plus-circle"></i>
                            <span class="d-none d-md-inline">@lang('erp::erp.create_new_product')</span></a></td>
                </tr>
                </tfoot>

            </table>
        </div>
    </div>
@endsection
