<?php

namespace TDevAgency\Erp\Commands;

use Illuminate\Foundation\Console\ModelMakeCommand as ModelMakeCommandParent;
use Illuminate\Support\Str;

class ModelMakeCommand extends ModelMakeCommandParent
{
    protected $name = 'cms:erp:make:model';

    /**
     * Get the destination class path.
     *
     * @param string $name
     * @return string
     */
    protected function getPath($name)
    {
        $name = Str::replaceFirst($this->rootNamespace(), '', $name);

        return TDEV_AGENCY_ERP_ROOT . 'src/' . str_replace('\\', '/', $name) . '.php';
    }

    protected function rootNamespace()
    {
        return 'TDevAgency\\Erp\\';
    }
    /**
     * Create a migration file for the model.
     *
     * @return void
     */
    protected function createMigration()
    {
        $table = Str::snake(Str::pluralStudly(class_basename($this->argument('name'))));

        if ($this->option('pivot')) {
            $table = Str::singular($table);
        }

        $this->call('make:migration', [
            'name' => "create_{$table}_table",
            '--create' => $table,
            '--path' => 'packages/tdev-agency/erp/database/migrations'
        ]);
    }

    /**
     * Create a controller for the model.
     *
     * @return void
     */
    protected function createController()
    {
        $controller = Str::studly(class_basename($this->argument('name')));

        $modelName = $this->qualifyClass($this->getNameInput());

        $this->call('cms:erp:make:controller', array_filter([
            'name'  => "{$controller}Controller",
            '--model' => $this->option('resource') || $this->option('api') ? $modelName : null,
            '--api' => $this->option('api'),
        ]));
    }
}
