<?php

namespace TDevAgency\Erp\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\App;
use Kyslik\ColumnSortable\Sortable;
use TDevAgency\Cms\Traits\Searchable;
use TDevAgency\Erp\Interfaces\ErpModel;
use TDevAgency\Erp\Traits\Containerable;

class Manufacture extends Model implements ErpModel
{
    use Sortable;
    use Searchable;
    use Containerable;

    public $sortable = ['manufacture_name'];
    protected $searchable = [
        'manufacture_name'
    ];
    protected $fillable = [
        'manufacture_name',
        'container_id',
        'manufacture_url',
        'manufacture_image',
    ];

    protected $sortableAs = ['products_count'];

    public function products()
    {
        return $this->hasMany(Product::class);
    }

    public function getImage($size = null)
    {
        return $this->getAttributeValue('manufacture_image') === null ? null :
            App::make('Erp\ImageHelper')->getImage($this, false, $size);
    }

    public function getImageWidth($size = null)
    {
        return $this->getAttributeValue('manufacture_image') === null ? null :
            App::make('Erp\ImageHelper')->getWidth($this, false, $size);
    }

    public function getImageHeight($size = null)
    {
        return $this->getAttributeValue('manufacture_image') === null ? null :
            App::make('Erp\ImageHelper')->getHeight($this, false, $size);
    }

    public function getName(): string
    {
        return $this->getAttributeValue('manufacture_name');
    }

    public function getImageName(): string
    {
        return $this->getAttributeValue('manufacture_image');
    }

    public function getId(): int
    {
        return $this->getAttributeValue('id');
    }

    public function getImageSizes(): array
    {
        return [
            'xl' => 768,
            'md' => 360,
            'sm' => 150,
            'xs' => 150, // is thumb 150*150
        ];
    }
}
